embassy-stm32

Crates

git

Versions

stm32f103re

Flavors

Clock

Enum Clock 

pub enum Clock {
    Auto,
}
ADC clock selection.

Only the modes of this chip’s ADCs exist; ADCs without a prescaler take their clock from the RCC as is.

Variants



Auto

Use the ADC kernel clock selected in the RCC, with the smallest prescaler that keeps the ADC clock within the limit of the chip.